==> sisyphus_control-3.0-py3-none-any.whl: sisyphus_control/track.py <==
from enum import IntEnum
from typing import Any, Dict

from .log import log_data_change


class Track:
    """Represents a track in the context of a Playlist or Table.

Every track known to a table is represented by a Track object whose parent
is the appropriate Table object.

Every track in a playlist is represented by a Track object whose parent is the
Playlist. If a given track appears multiple times in the playlist, each
occurrence is represented by its own Track object."""
    class ThumbnailSize(IntEnum):
        SMALL = 50
        MEDIUM = 100
        LARGE = 400

    def __init__(self, parent, transport, data: Dict[str, Any]):
        self.parent = parent
        self._transport = transport
        self._data = data

    def __str__(self) -> str:
        return self.name

    @property
    def id(self):
        """UUID of the track design, not of the Track instance."""
        return self._data["id"]

    @property
    def name(self) -> str:
        return self._data["name"]

    @property
    def is_in_playlist(self) -> bool:
        return "_index" in self._data

    @property
    def index_in_playlist(self) -> int:
        """
This track's index in the owning playlist when the playlist is not shuffled"""
        return self._data["_index"]

    async def play(self):
        if not self.is_in_playlist:
            await self._transport.post("set_track", self._data.data)
            await self.parent.play()
        else:
            await self.parent.play(self)

    def get_thumbnail_url(self, size):
        return "http://{host}:3001/thumbnail/{size}/{id}".format(
            host=self._transport.ip,
            size=size,
            id=self.id)

    def _set_data(self, data) -> bool:
        log_data_change(self._data, data)
        if self._data == data:
            # Debounce; the table tends to send a lot of events
            return False
        self._data = data
        return True

==> sisyphus_control-3.1.1-py3-none-any.whl: sisyphus_control/track.py <==
from enum import IntEnum
from typing import Any, Dict, Union

from sisyphus_control.data import Model

from . import table
from . import playlist
from .log import log_data_change
from .transport import TableTransport


class Track:
    """Represents a track in the context of a Playlist or Table.

Every track known to a table is represented by a Track object whose parent
is the appropriate Table object.

Every track in a playlist is represented by a Track object whose parent is the
Playlist. If a given track appears multiple times in the playlist, each
occurrence is represented by its own Track object."""
    class ThumbnailSize(IntEnum):
        SMALL = 50
        MEDIUM = 100
        LARGE = 400

    def __init__(self, parent: Union['playlist.Playlist', 'table.Table'], transport: TableTransport, data: Model):
        self.parent: Union['playlist.Playlist', 'table.Table'] = parent
        self._transport: TableTransport = transport
        self._data: Model = data

    def __str__(self) -> str:
        return self.name

    @property
    def id(self) -> str:
        """UUID of the track design, not of the Track instance."""
        return self._data["id"]

    @property
    def name(self) -> str:
        return self._data["name"]

    @property
    def is_in_playlist(self) -> bool:
        return "_index" in self._data

    @property
    def index_in_playlist(self) -> int:
        """
This track's index in the owning playlist when the playlist is not shuffled"""
        return self._data["_index"]

    async def play(self) -> None:
        if not self.is_in_playlist:
            await self._transport.post("set_track", self._data.data)
            await self.parent.play()
        else:
            # Ignore type error; if it's in a playlist the parent is the playlist, and that play() method takes a track
            await self.parent.play(self)  # type: ignore

    def get_thumbnail_url(self, size: int) -> str:
        return "http://{host}:3001/thumbnail/{size}/{id}".format(
            host=self._transport.ip,
            size=size,
            id=self.id)
